@@ -60,7 +60,7 @@
 #endif
 
 /* Some virtual keycodes are missing */
-#ifndef VM_OEM_PLUS
+#ifndef VK_OEM_PLUS
 #define VK_OEM_PLUS 0xBB
 #endif
 
@@ -282,6 +282,9 @@ struct _GdkGCWin32
   DWORD pen_style;
   DWORD *pen_dashes;		/* use for PS_USERSTYLE or step-by-step rendering */
   gint pen_num_dashes;
+  gint pen_dash_offset;
+  gboolean pen_double_dash;
+  HBRUSH pen_hbrbg;
 
   /* Following fields are valid while the GC exists as a Windows DC */
   HDC hdc;
@@ -337,13 +340,6 @@ GdkImage *_gdk_win32_copy_to_image      (GdkDrawable *drawable,
 					 gint         width,
 					 gint         height);
 
-GdkImage *_gdk_win32_setup_pixmap_image (GdkPixmap   *pixmap,
-					 GdkDrawable *drawable,
-					 gint         width,
-					 gint         height,
-					 gint         depth,
-					 guchar      *bits);
-
 void      _gdk_win32_blit               (gboolean              use_fg_bg,
 					 GdkDrawableImplWin32 *drawable,
 					 GdkGC       	       *gc,
@@ -364,24 +360,16 @@ HRGN	  _gdk_win32_gdkregion_to_hrgn  (GdkRegion   *region,
 					 gint         x_origin,
 					 gint         y_origin);
 
-void    _gdk_selection_property_store (GdkWindow *owner,
-                                       GdkAtom    type,
-                                       gint       format,
-                                       guchar    *data,
-                                       gint       length);
+void	_gdk_win32_adjust_client_rect   (GdkWindow *window,
+					 RECT      *RECT);
+
+void	_gdk_win32_get_adjusted_client_rect (GdkWindow *window,
+					     RECT      *RECT);
 
 void    _gdk_selection_property_delete (GdkWindow *);
 
 void    _gdk_dropfiles_store (gchar *data);
 
-gint    _gdk_utf8_to_ucs2         (wchar_t     *dest,
-                                   const gchar *src,
-                                   gint         src_len,
-                                   gint         dest_max);
-
-gchar  *_gdk_ucs2_to_utf8         (const wchar_t *src,
-				   gint           src_len);
-
 void    _gdk_wchar_text_handle    (GdkFont       *font,
 				   const wchar_t *wcstr,
 				   int            wclen,
@@ -415,6 +403,10 @@ gchar *_gdk_win32_psstyle_to_string    (DWORD        pen_style);
 gchar *_gdk_win32_psendcap_to_string   (DWORD        pen_style);
 gchar *_gdk_win32_psjoin_to_string     (DWORD        pen_style);
 gchar *_gdk_win32_message_to_string    (UINT         msg);
+gchar *_gdk_win32_key_to_string        (LONG         lParam);
+gchar *_gdk_win32_cf_to_string         (UINT         format);
+gchar *_gdk_win32_data_to_string       (const guchar*data,
+					int          nbytes);
 gchar *_gdk_win32_rect_to_string       (const RECT  *rect);
 
 gchar *_gdk_win32_gdkrectangle_to_string (const GdkRectangle *rect);
@@ -460,6 +452,16 @@ extern GdkWindow        *_gdk_parent_root;
 extern GdkDisplay       *_gdk_display;
 extern GdkScreen        *_gdk_screen;
 
+extern gint		 _gdk_num_monitors;
+extern GdkRectangle     *_gdk_monitors;
+
+/* Offsets to add to Windows coordinates (which are relative to the
+ * primary monitor's origin, and thus might be negative for monitors
+ * to the left and/or above the primary monitor) to get GDK
+ * coordinates, which should be non-negative on the whole screen.
+ */
+extern gint		 _gdk_offset_x, _gdk_offset_y;
+
 extern HDC		 _gdk_display_hdc;
 extern HINSTANCE	 _gdk_dll_hinstance;
 extern HINSTANCE	 _gdk_app_hmodule;
@@ -468,18 +470,23 @@ extern HINSTANCE	 _gdk_app_hmodule;
  * from a single thread anyway.
  */
 extern HKL		 _gdk_input_locale;
+extern gboolean		 _gdk_input_locale_is_ime;
 extern UINT		 _gdk_input_codepage;
 
 extern guint		 _gdk_keymap_serial;
+extern gboolean		 _gdk_keyboard_has_altgr;
+extern guint		 _scancode_rshift;
 
 /* Registered clipboard formats */
 extern WORD		 _cf_rtf;
 extern WORD		 _cf_utf8_string;
 
-/* GdkAtoms: Targets */
+/* GdkAtoms: targets */
 extern GdkAtom           _utf8_string;
-extern GdkAtom		 _compound_text;
+extern GdkAtom		 _targets;
+
 extern GdkAtom		 _text_uri_list;
+extern GdkAtom		 _image_bmp;
 
 /* DND selections */
 extern GdkAtom           _local_dnd;
@@ -488,8 +495,7 @@ extern GdkAtom		 _gdk_ole2_dnd;
 
 extern GdkAtom		 _gdk_selection_property;
 
-extern DWORD		 _windows_version;
-#define IS_WIN_NT()      (_windows_version < 0x80000000)
+extern GdkAtom		 _wm_transient_for;
 
 /* Options */
 extern gboolean		 _gdk_input_ignore_wintab;
@@ -497,8 +503,36 @@ extern gint		 _gdk_max_colors;
 
 #define GDK_WIN32_COLORMAP_DATA(cmap) ((GdkColormapPrivateWin32 *) GDK_COLORMAP (cmap)->windowing_data)
 
+/* TRUE while a user-initiated window move or resize operation is in progress */
+extern gboolean		 _sizemove_in_progress;
+
+/* TRUE when we are emptying the clipboard ourselves */
+extern gboolean		_ignore_destroy_clipboard;
+
+/* Mapping from registered clipboard format id (native) to
+ * corresponding GdkAtom
+ */
+extern GHashTable	*_format_atom_table;
+
+/* Hold the result of a delayed rendering */
+extern HGLOBAL		_delayed_rendering_data;
+
+HGLOBAL _gdk_win32_selection_convert_to_dib (HGLOBAL  hdata,
+					     GdkAtom  target);
+
+/* Convert a pixbuf to an HICON (or HCURSOR).  Supports alpha under
+ * Windows XP, thresholds alpha otherwise.
+ */
+HICON _gdk_win32_pixbuf_to_hicon   (GdkPixbuf *pixbuf);
+HICON _gdk_win32_pixbuf_to_hcursor (GdkPixbuf *pixbuf,
+				    gint       x_hotspot,
+				    gint       y_hotspot);
+gboolean _gdk_win32_pixbuf_to_hicon_supports_alpha (void);
+
 /* Initialization */
 void _gdk_windowing_window_init (void);
+void _gdk_root_window_size_init (void);
+void _gdk_monitor_init(void);
 void _gdk_visual_init (void);
 void _gdk_dnd_init    (void);
 void _gdk_windowing_image_init  (void);
