@@ -26,7 +26,6 @@
 
 #include <config.h>
 #include <string.h>
-#include "gtkalias.h"
 #include "gtkalignment.h"
 #include "gtkbutton.h"
 #include "gtklabel.h"
@@ -37,6 +36,7 @@
 #include "gtkstock.h"
 #include "gtkiconfactory.h"
 #include "gtkintl.h"
+#include "gtkalias.h"
 
 #define CHILD_SPACING     1
 
@@ -1424,7 +1424,7 @@ gtk_button_set_use_underline (GtkButton *button,
   
       gtk_button_construct_child (button);
       
-      g_object_notify (G_OBJECT (button), "use_underline");
+      g_object_notify (G_OBJECT (button), "use-underline");
     }
 }
 
@@ -1468,7 +1468,7 @@ gtk_button_set_use_stock (GtkButton *button,
   
       gtk_button_construct_child (button);
       
-      g_object_notify (G_OBJECT (button), "use_stock");
+      g_object_notify (G_OBJECT (button), "use-stock");
     }
 }
 
@@ -1514,7 +1514,7 @@ gtk_button_set_focus_on_click (GtkButton *button,
     {
       button->focus_on_click = focus_on_click;
       
-      g_object_notify (G_OBJECT (button), "focus_on_click");
+      g_object_notify (G_OBJECT (button), "focus-on-click");
     }
 }
 
@@ -1746,7 +1746,7 @@ gtk_button_grab_notify (GtkWidget *widget,
  * @image: a widget to set as the image for the button
  *
  * Set the image of @button to the given widget. Note that
- * it depends on the show-button-images setting whether the
+ * it depends on the gtk-button-images setting whether the
  * image will be displayed or not.
  *
  * Since: 2.6
@@ -1773,6 +1773,8 @@ gtk_button_set_image (GtkButton *button,
  * This may have been explicitly set by gtk_button_set_image()
  * or constructed by gtk_button_new_from_stock().
  *
+ * Return value: a #GtkWidget or %NULL in case there is no image
+ *
  * Since: 2.6
  */
 GtkWidget *
@@ -1787,4 +1789,5 @@ gtk_button_get_image (GtkButton *button)
   return priv->image;
 }
   
-  
+#define __GTK_BUTTON_C__
+#include "gtkaliasdef.c"  
