@@ -56,7 +56,6 @@
 #include <string.h>
 #include "gdk.h"
 
-#include "gtkalias.h"
 #include "gtkmain.h"
 #include "gtkselection.h"
 #include "gdk-pixbuf/gdk-pixbuf.h"
@@ -65,6 +64,12 @@
 #include "x11/gdkx.h"
 #endif
 
+#ifdef GDK_WINDOWING_WIN32
+#include "win32/gdkwin32.h"
+#endif
+
+#include "gtkalias.h"
+
 #undef DEBUG_SELECTION
 
 /* Maximum size of a sent chunk, in bytes. Also the default size of
@@ -80,7 +85,7 @@
 #define GTK_SELECTION_MAX_SIZE(display) G_MAXINT
 #endif
 
-#define IDLE_ABORT_TIME 300
+#define IDLE_ABORT_TIME 30
 
 enum {
   INCR,
@@ -177,6 +182,16 @@ static const char gtk_selection_handler_key[] = "gtk-selection-handlers";
  * Target lists
  */
 
+
+/**
+ * gtk_target_list_new:
+ * @targets: Pointer to an array of #GtkTargetEntry
+ * @ntargets:  number of entries in @targets.
+ * 
+ * Creates a new #GtkTargetList from an array of #GtkTargetEntry.
+ * 
+ * Return value: the new #GtkTargetList.
+ **/
 GtkTargetList *
 gtk_target_list_new (const GtkTargetEntry *targets,
 		     guint                 ntargets)
@@ -191,6 +206,13 @@ gtk_target_list_new (const GtkTargetEntry *targets,
   return result;
 }
 
+/**
+ * gtk_target_list_ref:
+ * @list:  a #GtkTargetList
+ * 
+ * Increases the reference count of a #GtkTargetList by one.
+ *
+ **/
 void               
 gtk_target_list_ref (GtkTargetList *list)
 {
@@ -199,6 +221,13 @@ gtk_target_list_ref (GtkTargetList *list)
   list->ref_count++;
 }
 
+/**
+ * gtk_target_list_unref:
+ * @list: a #GtkTargetList
+ * 
+ * Decreases the reference count of a #GtkTargetList by one.
+ * If the resulting reference count is zero, frees the list.
+ **/
 void               
 gtk_target_list_unref (GtkTargetList *list)
 {
@@ -222,6 +251,15 @@ gtk_target_list_unref (GtkTargetList *list)
     }
 }
 
+/**
+ * gtk_target_list_add:
+ * @list:  a #GtkTargetList
+ * @target: the interned atom representing the target
+ * @flags: the flags for this target
+ * @info: an ID that will be passed back to the application
+ * 
+ * Appends another target to a #GtkTargetList.
+ **/
 void 
 gtk_target_list_add (GtkTargetList *list,
 		     GdkAtom        target,
@@ -275,7 +313,7 @@ init_atoms (void)
  * @list: a #GtkTargetList
  * @info: an ID that will be passed back to the application
  * 
- * Adds the text targets supported by #GtkSelection to
+ * Appends the text targets supported by #GtkSelection to
  * the target list. All targets are added with the same @info.
  * 
  * Since: 2.6
@@ -306,7 +344,7 @@ gtk_target_list_add_text_targets (GtkTargetList *list,
  * @writable: whether to add only targets for which GTK+ knows
  *   how to convert a pixbuf into the format
  * 
- * Adds the image targets supported by #GtkSelection to
+ * Appends the image targets supported by #GtkSelection to
  * the target list. All targets are added with the same @info.
  * 
  * Since: 2.6
@@ -324,6 +362,25 @@ gtk_target_list_add_image_targets (GtkTargetList *list,
 
   formats = gdk_pixbuf_get_formats ();
 
+  /* Make sure png comes first */
+  for (f = formats; f; f = f->next)
+    {
+      GdkPixbufFormat *fmt = f->data;
+      gchar *name;
+
+      name = gdk_pixbuf_format_get_name (fmt);
+      if (strcmp (name, "png") == 0)
+	{
+	  formats = g_slist_delete_link (formats, f);
+	  formats = g_slist_prepend (formats, fmt);
+	  g_free (name);
+
+	  break;
+	}
+
+      g_free (name);
+    }  
+
   for (f = formats; f; f = f->next)
     {
       GdkPixbufFormat *fmt = f->data;
@@ -348,7 +405,7 @@ gtk_target_list_add_image_targets (GtkTargetList *list,
  * @list: a #GtkTargetList
  * @info: an ID that will be passed back to the application
  * 
- * Adds the URI targets supported by #GtkSelection to
+ * Appends the URI targets supported by #GtkSelection to
  * the target list. All targets are added with the same @info.
  * 
  * Since: 2.6
@@ -364,6 +421,14 @@ gtk_target_list_add_uri_targets (GtkTargetList *list,
   gtk_target_list_add (list, text_uri_list_atom, 0, info);  
 }
 
+/**
+ * gtk_target_list_add_table:
+ * @list: a #GtkTargetList
+ * @targets: the table of #GtkTargetEntry
+ * @ntargets: number of targets in the table
+ * 
+ * Prepends a table of #GtkTargetEntry to a target list.
+ **/
 void               
 gtk_target_list_add_table (GtkTargetList        *list,
 			   const GtkTargetEntry *targets,
@@ -382,6 +447,13 @@ gtk_target_list_add_table (GtkTargetList        *list,
     }
 }
 
+/**
+ * gtk_target_list_remove:
+ * @list: a #GtkTargetList
+ * @target: the interned atom representing the target
+ * 
+ * Removes a target from a target list.
+ **/
 void 
 gtk_target_list_remove (GtkTargetList *list,
 			GdkAtom            target)
@@ -409,6 +481,16 @@ gtk_target_list_remove (GtkTargetList *list,
     }
 }
 
+/**
+ * gtk_target_list_find:
+ * @list: a #GtkTargetList
+ * @target: an interned atom representing the target to search for
+ * @info: a pointer to the location to store application info for target
+ * 
+ * Looks up a given target in a #GtkTargetList.
+ * 
+ * Return value: %TRUE if the target was found, otherwise %FALSE
+ **/
 gboolean
 gtk_target_list_find (GtkTargetList *list,
 		      GdkAtom        target,
@@ -568,19 +650,6 @@ gtk_selection_owner_set (GtkWidget *widget,
 					      selection, time);
 }
 
-/*************************************************************
- * gtk_selection_add_target
- *     Add specified target to list of supported targets
- *
- *   arguments:
- *     widget:	   The widget for which this target applies
- *     selection:
- *     target:
- *     info:       guint to pass to to the selection_get signal 
- *
- *   results:
- *************************************************************/
-
 typedef struct _GtkSelectionTargetList GtkSelectionTargetList;
 
 struct _GtkSelectionTargetList {
@@ -681,6 +750,16 @@ gtk_selection_clear_targets (GtkWidget *widget,
   g_object_set_data (G_OBJECT (widget), gtk_selection_handler_key, lists);
 }
 
+/**
+ * gtk_selection_add_target:
+ * @widget:  a #GtkTarget
+ * @selection: the selection
+ * @target: target to add.
+ * @info: A unsigned integer which will be passed back to the application.
+ * 
+ * Appends a specified target to the list of supported targets for a 
+ * given widget and selection.
+ **/
 void 
 gtk_selection_add_target (GtkWidget	    *widget, 
 			  GdkAtom	     selection,
@@ -694,8 +773,21 @@ gtk_selection_add_target (GtkWidget	    *widget,
 
   list = gtk_selection_target_list_get (widget, selection);
   gtk_target_list_add (list, target, 0, info);
+#ifdef GDK_WINDOWING_WIN32
+  gdk_win32_selection_add_targets (widget->window, selection, 1, &target);
+#endif
 }
 
+/**
+ * gtk_selection_add_targets:
+ * @widget: a #GtkWidget
+ * @selection: the selection
+ * @targets: a table of targets to add
+ * @ntargets:  number of entries in @targets
+ * 
+ * Prepends a table of targets to the list of supported targets
+ * for a given widget and selection.
+ **/
 void 
 gtk_selection_add_targets (GtkWidget            *widget, 
 			   GdkAtom               selection,
@@ -710,20 +802,30 @@ gtk_selection_add_targets (GtkWidget            *widget,
   
   list = gtk_selection_target_list_get (widget, selection);
   gtk_target_list_add_table (list, targets, ntargets);
+
+#ifdef GDK_WINDOWING_WIN32
+  {
+    int i;
+    GdkAtom *atoms = g_new (GdkAtom, ntargets);
+
+    for (i = 0; i < ntargets; ++i)
+      atoms[i] = gdk_atom_intern (targets[i].target, FALSE);
+    gdk_win32_selection_add_targets (widget->window, selection, ntargets, atoms);
+    g_free (atoms);
+  }
+#endif
 }
 
 
-/*************************************************************
+/**
  * gtk_selection_remove_all:
- *     Removes all handlers and unsets ownership of all 
- *     selections for a widget. Called when widget is being
- *     destroyed
- *     
- *   arguments:
- *     widget:	  The widget
- *   results:
- *************************************************************/
-
+ * @widget: a #GtkWidget 
+ * 
+ * Removes all handlers and unsets ownership of all 
+ * selections for a widget. Called when widget is being
+ * destroyed. This function will not generally be
+ * called by applications.
+ **/
 void
 gtk_selection_remove_all (GtkWidget *widget)
 {
@@ -774,29 +876,27 @@ gtk_selection_remove_all (GtkWidget *widget)
   gtk_selection_target_list_remove (widget);
 }
 
-/*************************************************************
- * gtk_selection_convert:
- *     Request the contents of a selection. When received, 
- *     a "selection_received" signal will be generated.
- *
- *   arguments:
- *     widget:	   The widget which acts as requestor
- *     selection:  Which selection to get
- *     target:	   Form of information desired (e.g., STRING)
- *     time:	   Time of request (usually of triggering event)
- *		   In emergency, you could use GDK_CURRENT_TIME
- *
- *   results:
- *     TRUE if requested succeeded. FALSE if we could not process
- *     request. (e.g., there was already a request in process for
- *     this widget). 
- *************************************************************/
 
+/**
+ * gtk_selection_convert:
+ * @widget: The widget which acts as requestor
+ * @selection: Which selection to get
+ * @target: Form of information desired (e.g., STRING)
+ * @time_: Time of request (usually of triggering event)
+       In emergency, you could use #GDK_CURRENT_TIME
+ * 
+ * Requests the contents of a selection. When received, 
+ * a "selection_received" signal will be generated.
+ * 
+ * Return value: %TRUE if requested succeeded. %FALSE if we could not process
+ *          request. (e.g., there was already a request in process for
+ *          this widget).
+ **/
 gboolean
 gtk_selection_convert (GtkWidget *widget, 
 		       GdkAtom	  selection, 
 		       GdkAtom	  target,
-		       guint32	  time)
+		       guint32	  time_)
 {
   GtkRetrievalInfo *info;
   GList *tmp_list;
@@ -859,14 +959,14 @@ gtk_selection_convert (GtkWidget *widget,
 	{
 	  gtk_selection_invoke_handler (owner_widget, 
 					&selection_data,
-					time);
+					time_);
 	  
 	  gtk_selection_retrieval_report (info,
 					  selection_data.type, 
 					  selection_data.format,
 					  selection_data.data,
 					  selection_data.length,
-					  time);
+					  time_);
 	  
 	  g_free (selection_data.data);
 	  
@@ -878,25 +978,25 @@ gtk_selection_convert (GtkWidget *widget,
   /* Otherwise, we need to go through X */
   
   current_retrievals = g_list_append (current_retrievals, info);
-  gdk_selection_convert (widget->window, selection, target, time);
+  gdk_selection_convert (widget->window, selection, target, time_);
   g_timeout_add (1000, (GSourceFunc) gtk_selection_retrieval_timeout, info);
   
   return TRUE;
 }
 
-/*************************************************************
- * gtk_selection_data_set:
- *     Store new data into a GtkSelectionData object. Should
- *     _only_ by called from a selection handler callback.
- *     Null terminates the stored data.
- *   arguments:
- *     type:	the type of selection data
- *     format:	format (number of bits in a unit)
- *     data:	pointer to the data (will be copied)
- *     length:	length of the data
- *   results:
- *************************************************************/
 
+/**
+ * gtk_selection_data_set:
+ * @selection_data: a pointer to a #GtkSelectionData structure.
+ * @type: the type of selection data
+ * @format: format (number of bits in a unit)
+ * @data: pointer to the data (will be copied)
+ * @length: length of the data
+ * 
+ * Stores new data into a #GtkSelectionData object. Should
+ * <emphasis>only</emphasis> be called from a selection handler callback.
+ * Zero-terminates the stored data.
+ **/
 void 
 gtk_selection_data_set (GtkSelectionData *selection_data,
 			GdkAtom		  type,
@@ -1266,11 +1366,8 @@ gtk_selection_data_set_pixbuf (GtkSelectionData *selection_data,
 	    {
 	      str = NULL;
 	      type = gdk_pixbuf_format_get_name (fmt),
-	      result = gdk_pixbuf_save_to_buffer (pixbuf,
-						  &str,
-						  &len,
-						  type,
-						  NULL);
+	      result = gdk_pixbuf_save_to_buffer (pixbuf, &str, &len,
+						  type, NULL, NULL);
 	      if (result) 
 		gtk_selection_data_set (selection_data,
 					atom, 8, (guchar *)str, len);
@@ -1310,20 +1407,23 @@ gtk_selection_data_get_pixbuf (GtkSelectionData *selection_data)
   GdkPixbufLoader *loader;
   GdkPixbuf *result = NULL;
 
-  loader = gdk_pixbuf_loader_new ();
-  
-  if (gdk_pixbuf_loader_write (loader, 
-			       selection_data->data,
-			       selection_data->length,
-			       NULL))
-    result = gdk_pixbuf_loader_get_pixbuf (loader);
-  
-  if (result)
-    g_object_ref (result);
+  if (selection_data->length > 0)
+    {
+      loader = gdk_pixbuf_loader_new ();
+      
+      if (gdk_pixbuf_loader_write (loader, 
+				   selection_data->data,
+				   selection_data->length,
+				   NULL))
+	result = gdk_pixbuf_loader_get_pixbuf (loader);
+      
+      if (result)
+	g_object_ref (result);
+      
+      gdk_pixbuf_loader_close (loader, NULL);
+      g_object_unref (loader);
+    }
 
-  gdk_pixbuf_loader_close (loader, NULL);
-  g_object_unref (loader);
-  
   return result;
 }
 
@@ -2470,6 +2570,14 @@ gtk_selection_default_handler (GtkWidget	*widget,
 }
 
 
+/**
+ * gtk_selection_data_copy:
+ * @selection_data: a pointer to a #GtkSelectionData structure.
+ * 
+ * Makes a copy of a #GtkSelectionData structure and its data.
+ * 
+ * Return value: a pointer to a copy of @data.
+ **/
 GtkSelectionData*
 gtk_selection_data_copy (GtkSelectionData *selection_data)
 {
@@ -2489,6 +2597,13 @@ gtk_selection_data_copy (GtkSelectionData *selection_data)
   return new_data;
 }
 
+/**
+ * gtk_selection_data_free:
+ * @data: a pointer to a #GtkSelectionData structure.
+ * 
+ * Frees a #GtkSelectionData structure returned from
+ * gtk_selection_data_copy().
+ **/
 void
 gtk_selection_data_free (GtkSelectionData *data)
 {
@@ -2532,3 +2647,6 @@ gtk_selection_bytes_per_item (gint format)
     }
   return 0;
 }
+
+#define __GTK_SELECTION_C__
+#include "gtkaliasdef.c"
